@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: amazons3.py 1086 2014-10-07 22:29:07Z pronovic $
 # Purpose  : Cedar Backup tool to synchronize an Amazon S3 bucket.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -60,7 +59,7 @@ import json
 import chardet
 import warnings
 
-# Cedar Backup modules 
+# Cedar Backup modules
 from CedarBackup2.release import AUTHOR, EMAIL, VERSION, DATE, COPYRIGHT
 from CedarBackup2.filesystem import FilesystemList
 from CedarBackup2.cli import setupLogging, DEFAULT_LOGFILE, DEFAULT_OWNERSHIP, DEFAULT_MODE
@@ -77,9 +76,9 @@ logger = logging.getLogger("CedarBackup2.log.tools.amazons3")
 AWS_COMMAND   = [ "aws" ]
 
 SHORT_SWITCHES     = "hVbql:o:m:OdsDvw"
-LONG_SWITCHES      = [ 'help', 'version', 'verbose', 'quiet', 
-                       'logfile=', 'owner=', 'mode=', 
-                       'output', 'debug', 'stack', 'diagnostics', 
+LONG_SWITCHES      = [ 'help', 'version', 'verbose', 'quiet',
+                       'logfile=', 'owner=', 'mode=',
+                       'output', 'debug', 'stack', 'diagnostics',
                        'verifyOnly', 'ignoreWarnings', ]
 
 
@@ -97,7 +96,7 @@ class Options(object):
    Class representing command-line options for the cback-amazons3-sync script.
 
    The C{Options} class is a Python object representation of the command-line
-   options of the cback script.  
+   options of the cback script.
 
    The object representation is two-way: a command line string or a list of
    command line arguments can be used to create an C{Options} object, and then
@@ -393,7 +392,7 @@ class Options(object):
       """
       if value is not None:
          if len(value) < 1:
-            raise ValueError("The logfile parameter must be a non-empty string.") 
+            raise ValueError("The logfile parameter must be a non-empty string.")
       self._logfile = encodePath(value)
 
    def _getLogfile(self):
@@ -627,7 +626,7 @@ class Options(object):
       long option names (i.e. --version rather than -V).  The resulting list
       will be suitable for passing back to the constructor in the
       C{argumentList} parameter.  Unlike L{buildArgumentString}, string
-      arguments are not quoted here, because there is no need for it.  
+      arguments are not quoted here, because there is no need for it.
 
       Unless the C{validate} parameter is C{False}, the L{Options.validate}
       method will be called (with its default arguments) against the
@@ -753,7 +752,7 @@ class Options(object):
       any validation as to whether required elements exist or whether elements
       exist in the proper combination (instead, that's the job of the
       L{validate} method).
-   
+
       For any of the options which supply parameters, if the option is
       duplicated with long and short switches (i.e. C{-l} and a C{--logfile})
       then the long switch is used.  If the same option is duplicated with the
@@ -829,7 +828,7 @@ def cli():
 
    A different error code is returned for each type of failure:
 
-      - C{1}: The Python interpreter version is < 2.5
+      - C{1}: The Python interpreter version is < 2.7
       - C{2}: Error processing command-line arguments
       - C{3}: Error configuring logging
       - C{5}: Backup was interrupted with a CTRL-C or similar
@@ -842,12 +841,12 @@ def cli():
    @return: Error code as described above.
    """
    try:
-      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5]:
-         sys.stderr.write("Python version 2.5 or greater required.\n")
+      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 7]:
+         sys.stderr.write("Python 2 version 2.7 or greater required.\n")
          return 1
    except:
       # sys.version_info isn't available before 2.0
-      sys.stderr.write("Python version 2.5 or greater required.\n")
+      sys.stderr.write("Python 2 version 2.7 or greater required.\n")
       return 1
 
    try:
@@ -874,8 +873,8 @@ def cli():
       return 3
 
    logger.info("Cedar Backup Amazon S3 sync run started.")
-   logger.info("Options were [%s]" % options)
-   logger.info("Logfile is [%s]" % logfile)
+   logger.info("Options were [%s]", options)
+   logger.info("Logfile is [%s]", logfile)
    Diagnostics().logDiagnostics(method=logger.info)
 
    if options.stacktrace:
@@ -888,7 +887,7 @@ def cli():
          logger.info("Cedar Backup Amazon S3 sync run completed with status 5.")
          return 5
       except Exception, e:
-         logger.error("Error executing backup: %s" % e)
+         logger.error("Error executing backup: %s", e)
          logger.info("Cedar Backup Amazon S3 sync run completed with status 6.")
          return 6
 
@@ -1018,7 +1017,7 @@ def _executeAction(options):
 def _buildSourceFiles(sourceDir):
    """
    Build a list of files in a source directory
-   @param sourceDir: Local source directory 
+   @param sourceDir: Local source directory
    @return: FilesystemList with contents of source directory
    """
    if not os.path.isdir(sourceDir):
@@ -1035,8 +1034,8 @@ def _buildSourceFiles(sourceDir):
 def _checkSourceFiles(sourceDir, sourceFiles):
    """
    Check source files, trying to guess which ones will have encoding problems.
-   @param sourceDir: Local source directory 
-   @param sourceDir: Local source directory 
+   @param sourceDir: Local source directory
+   @param sourceDir: Local source directory
    @raises ValueError: If a problem file is found
    @see U{http://opensourcehacker.com/2011/09/16/fix-linux-filename-encodings-with-python/}
    @see U{http://serverfault.com/questions/82821/how-to-tell-the-language-encoding-of-a-filename-on-linux}
@@ -1054,12 +1053,12 @@ def _checkSourceFiles(sourceDir, sourceFiles):
          try:
             target = source.encode(encoding)
             if source != target:
-               logger.error("Inconsistent encoding for [%s]: got %s, but need %s" % (entry, result["encoding"], encoding))
+               logger.error("Inconsistent encoding for [%s]: got %s, but need %s", entry, result["encoding"], encoding)
                failed = True
          except UnicodeEncodeError:
-            logger.error("Inconsistent encoding for [%s]: got %s, but need %s" % (entry, result["encoding"], encoding))
+            logger.error("Inconsistent encoding for [%s]: got %s, but need %s", entry, result["encoding"], encoding)
             failed = True
-      
+
       if not failed:
          logger.info("Completed checking source filename encoding (no problems found).")
       else:
@@ -1077,8 +1076,8 @@ def _checkSourceFiles(sourceDir, sourceFiles):
 def _synchronizeBucket(sourceDir, s3BucketUrl):
    """
    Synchronize a local directory to an Amazon S3 bucket.
-   @param sourceDir: Local source directory 
-   @param s3BucketUrl: Target S3 bucket URL 
+   @param sourceDir: Local source directory
+   @param s3BucketUrl: Target S3 bucket URL
    """
    logger.info("Synchronizing local source directory up to Amazon S3.")
    args = [ "s3", "sync", sourceDir, s3BucketUrl, "--delete", "--recursive", ]
@@ -1094,9 +1093,9 @@ def _synchronizeBucket(sourceDir, s3BucketUrl):
 def _verifyBucketContents(sourceDir, sourceFiles, s3BucketUrl):
    """
    Verify that a source directory is equivalent to an Amazon S3 bucket.
-   @param sourceDir: Local source directory 
+   @param sourceDir: Local source directory
    @param sourceFiles: Filesystem list containing contents of source directory
-   @param s3BucketUrl: Target S3 bucket URL 
+   @param s3BucketUrl: Target S3 bucket URL
    """
    # As of this writing, the documentation for the S3 API that we're using
    # below says that up to 1000 elements at a time are returned, and that we
@@ -1140,11 +1139,11 @@ def _verifyBucketContents(sourceDir, sourceFiles, s3BucketUrl):
          key = entry.replace(sourceDir, "")
          size = long(os.stat(entry).st_size)
          if not key in contents:
-            logger.error("File was apparently not uploaded: [%s]" % entry)
+            logger.error("File was apparently not uploaded: [%s]", entry)
             failed = True
          else:
             if size != contents[key]:
-               logger.error("File size differs [%s]: expected %s bytes but got %s bytes" % (entry, size, contents[key]))
+               logger.error("File size differs [%s]: expected %s bytes but got %s bytes", entry, size, contents[key])
                failed = True
 
    if not failed:
