@@ -25,9 +25,8 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.5)
+# Language : Python 2 (>= 2.7)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: span.py 1084 2014-10-07 21:52:19Z pronovic $
 # Purpose  : Spans staged data among multiple discs
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -61,7 +60,7 @@ import os
 import logging
 import tempfile
 
-# Cedar Backup modules 
+# Cedar Backup modules
 from CedarBackup2.release import AUTHOR, EMAIL, VERSION, DATE, COPYRIGHT
 from CedarBackup2.util import displayBytes, convertSize, mount, unmount
 from CedarBackup2.util import UNIT_SECTORS, UNIT_BYTES
@@ -94,7 +93,7 @@ class SpanOptions(Options):
 
    Most of the cback command-line options are exactly what we need here --
    logfile path, permissions, verbosity, etc.  However, we need to make a few
-   tweaks since we don't accept any actions.  
+   tweaks since we don't accept any actions.
 
    Also, a few extra command line options that we accept are really ignored
    underneath.  I just don't care about that for a tool like this.
@@ -131,7 +130,7 @@ def cli():
 
    A different error code is returned for each type of failure:
 
-      - C{1}: The Python interpreter version is < 2.5
+      - C{1}: The Python interpreter version is < 2.7
       - C{2}: Error processing command-line arguments
       - C{3}: Error configuring logging
       - C{4}: Error parsing indicated configuration file
@@ -145,12 +144,12 @@ def cli():
    @return: Error code as described above.
    """
    try:
-      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 5]:
-         sys.stderr.write("Python version 2.5 or greater required.\n")
+      if map(int, [sys.version_info[0], sys.version_info[1]]) < [2, 7]:
+         sys.stderr.write("Python 2 version 2.7 or greater required.\n")
          return 1
    except:
       # sys.version_info isn't available before 2.0
-      sys.stderr.write("Python version 2.5 or greater required.\n")
+      sys.stderr.write("Python 2 version 2.7 or greater required.\n")
       return 1
 
    try:
@@ -177,8 +176,8 @@ def cli():
       return 3
 
    logger.info("Cedar Backup 'span' utility run started.")
-   logger.info("Options were [%s]" % options)
-   logger.info("Logfile is [%s]" % logfile)
+   logger.info("Options were [%s]", options)
+   logger.info("Logfile is [%s]", logfile)
 
    if options.config is None:
       logger.debug("Using default configuration file.")
@@ -188,11 +187,11 @@ def cli():
       configPath = options.config
 
    try:
-      logger.info("Configuration path is [%s]" % configPath)
+      logger.info("Configuration path is [%s]", configPath)
       config = Config(xmlPath=configPath)
       setupPathResolver(config)
    except Exception, e:
-      logger.error("Error reading or handling configuration: %s" % e)
+      logger.error("Error reading or handling configuration: %s", e)
       logger.info("Cedar Backup 'span' utility run completed with status 4.")
       return 4
 
@@ -206,7 +205,7 @@ def cli():
          logger.info("Cedar Backup 'span' utility run completed with status 5.")
          return 5
       except Exception, e:
-         logger.error("Error executing backup: %s" % e)
+         logger.error("Error executing backup: %s", e)
          logger.info("Cedar Backup 'span' utility run completed with status 6.")
          return 6
 
@@ -382,7 +381,7 @@ def _executeAction(options, config):
    if not _getYesNoAnswer("Continue?", default="Y"):
       return
    print "==="
-   
+
    happy = False
    while not happy:
       print ""
@@ -414,7 +413,7 @@ def _executeAction(options, config):
       counter = 0
       for item in spanSet:
          counter += 1
-         print "Disc %d: %d files, %s, %.2f%% utilization" % (counter, len(item.fileList), 
+         print "Disc %d: %d files, %s, %.2f%% utilization" % (counter, len(item.fileList),
                                                               displayBytes(item.size), item.utilization)
       print ""
       if _getYesNoAnswer("Accept this solution?", default="Y"):
@@ -458,7 +457,7 @@ def _findDailyDirs(stagingDir):
    directories, and a BackupFileList containing all files among those staging
    directories.
 
-   @param stagingDir: Configured staging directory 
+   @param stagingDir: Configured staging directory
 
    @return: Tuple (staging dirs, backup file list)
    """
@@ -495,7 +494,7 @@ def _getWriter(config):
    Gets a writer and media capacity from store configuration.
    Returned is a writer and a media capacity in bytes.
    @param config: Cedar Backup configuration
-   @return: Tuple of (writer, mediaCapacity) 
+   @return: Tuple of (writer, mediaCapacity)
    """
    writer = createWriter(config)
    mediaCapacity = convertSize(writer.media.capacity, UNIT_SECTORS, UNIT_BYTES)
@@ -539,7 +538,7 @@ def _discInitializeImage(config, writer, spanItem):
       except KeyboardInterrupt, e:
          raise e
       except Exception, e:
-         logger.error("Failed to initialize image: %s" % e)
+         logger.error("Failed to initialize image: %s", e)
          if not _getYesNoAnswer("Retry initialization step?", default="Y"):
             raise e
          print "Ok, attempting retry."
@@ -561,7 +560,7 @@ def _discWriteImage(config, writer):
       except KeyboardInterrupt, e:
          raise e
       except Exception, e:
-         logger.error("Failed to write image: %s" % e)
+         logger.error("Failed to write image: %s", e)
          if not _getYesNoAnswer("Retry this step?", default="Y"):
             raise e
          print "Ok, attempting retry."
@@ -586,7 +585,7 @@ def _discConsistencyCheck(config, writer, spanItem):
          except KeyboardInterrupt, e:
             raise e
          except Exception, e:
-            logger.error("Consistency check failed: %s" % e)
+            logger.error("Consistency check failed: %s", e)
             if not _getYesNoAnswer("Retry the consistency check?", default="Y"):
                raise e
             if _getYesNoAnswer("Rewrite the disc first?", default="N"):
@@ -636,7 +635,7 @@ def _consistencyCheck(config, fileList):
       compareDigestMaps(sourceListDigest, discListDigest, verbose=True)
       logger.info("Consistency check completed.  No problems found.")
    finally:
-      unmount(mountPoint, True, 5, 1)  # try 5 times, and remove mount point when done 
+      unmount(mountPoint, True, 5, 1)  # try 5 times, and remove mount point when done
 
 
 #########################################################################
